# Esercizio Lotti

# DATI
param nT;		# Numero di periodi
set T := 1..nT;	# Insieme indicizzato di periodi
param nP;		# Numero di prodotti
set P := 1..nP;	# Insieme indicizzato di prodotti
param cf {T};	# Costo fisso per ogni periodo []
param c {P,T};	# Costi unitari di produzione [/unit]
param cs {P,T};	# Costi unitari di stoccaggio [/(unit di prodotto * periodo)
param q {P,T};	# Capacit produttiva [unit]
param d {P,T};	# Domanda per ogni prodotto ed ogni periodo [unit]

# VARIABILI
var x {p in P,t in T} >=0, <=q[p,t];	# Produzione [unit]
var y {T} binary;						# Uso del periodo produttivo
var s {P,T} >=0;						# Giacenza per ogni prodotto all'inizio di ogni periodo [unit]

# VINCOLI
# Definizione della giacenza e soddisfacimento della domanda [unit]
subject to Flow_conservation {t in T, p in P: t < nT}:
  s[p,t] + x[p,t] = s[p,t+1] + d[p,t];
subject to No_rimanenze {p in P}:
  s[p,nT] + x[p,nT] = d[p,nT];
subject to No_scorte_iniziali {p in P}:
  s[p,1] = 0;

# Produzione solo nei periodi utilizzati
subject to Periodi {t in T, p in P}:
  x[p,t] <= q[p,t] * y[t];

# OBIETTIVO
# Minimizzare i costi totali
minimize z: sum {t in T, p in P} (c[p,t] * x[p,t] + cs[p,t] * s[p,t]) + sum {t in T} cf[t] * y[t];

########################
data;

param nT := 6;
param nP := 3;

param cf :=
   1     1300
   2     1500
   3     1700
   4     1500
   5     1000
   6      800;

param c:      1    2    3    4    5    6 :=
    1        12   10   15   17   17   15
    2        24   21   28   20   25   25
    3        18   15   20   18   18   20;

param cs:     1    2    3    4    5    6 :=
    1         5    5    8    8    4    2
    2         8    9   12   15   16   10
    3         6    7    7    8    4    4;

param q:      1    2    3    4    5    6 :=
    1        75   75   75   75   80   80
    2        50   50   55   55   60   65
    3        50   50   40   40   50   50;

param d:      1    2    3    4    5    6 :=
    1        15   15   15   15   15   15
    2        25   25   35   35   25   25
    3        10    5    5    5   10   15;

end;
